%Load data
load('AVsaccade.mat');
%Load plotting colors
load ('plotColor3');

%Sort data into modalities
visual = sac(sac(:,7) == 1,2); 
audio = sac(sac(:,7) == 2 | sac(:,7) == 3,2); 
audVis = sac(sac(:,7) == 4 | sac(:,7) == 5,2); 

%Create discrete probability distributions
binEdges = 0:20:600; 
aCountP = MakePD(audio,binEdges);
vCountP = MakePD(visual,binEdges);
avCountP = MakePD(audVis,binEdges); 

%Plot data
figure;
plot(binEdges,vCountP,'Color', c1', 'LineWidth',1.5, 'Marker', 'none','MarkerFaceColor', c1,'LineStyle',':'); hold on;
plot(binEdges,aCountP, 'Color', c2, 'LineWidth',1.5, 'Marker', 'none','MarkerFaceColor', c2,'LineStyle',':'); hold on; 
plot(binEdges,avCountP, 'Color', c3, 'LineWidth',1.5, 'Marker', 'none','MarkerFaceColor', c3,'LineStyle',':'); hold on; 
xlabel('Reaction Times');
ylabel('P(Observation)');
legend('Visual','Auditory','AudioVisual'); 
axis square
box off
title('Reaction Times to Stimulus Modalities')

%Get initial parameters
vTheta = EstExGaussInitial(visual); 
aTheta = EstExGaussInitial(audio); 
avTheta = EstExGaussInitial(audVis); 

%Perform likelihood minimization (download fminsearch from MATLAB exchange)
visParams = fminsearch(@MaxLkh,vTheta,[],visual); 
audParams = fminsearch(@MaxLkh,aTheta,[],audio); 
avParams = fminsearch(@MaxLkh,avTheta,[],audVis); 

%Simulate data from fitted parameters
plotBin = 0:0.1:600; %Points to evaluate on
simulatedVis = ExGauss(plotBin,visParams); 
simulatedAudio = ExGauss(plotBin,audParams); 
simulatedAV = ExGauss(plotBin,avParams); 

%Plot simulated data on top of original
plot(plotBin,simulatedVis,'Color', c1', 'LineWidth',2, 'Marker', 'none','MarkerFaceColor', c1,'LineStyle','-'); hold on;
plot(plotBin,simulatedAudio,'Color', c2', 'LineWidth',2, 'Marker', 'none','MarkerFaceColor', c1,'LineStyle','-'); hold on; 
plot(plotBin,simulatedAV,'Color', c3', 'LineWidth',2, 'Marker', 'none','MarkerFaceColor', c1,'LineStyle','-'); hold on;

%save parameters
%save('FitParams', 'visParams', 'audParams', 'avParams'); 


